function wfgeneration, dim, length, L0, r0, lambda, SEED=seed 
;
; wave-front (wf) generation following Kolmogorov or von Karman model
;
; dim    = wf linear dimension [px],
; length = wf physical length [m],
; L0     = wf outer-scale [m],
; seed   = random generation seed (OPTIONAL),
; r0     = Fried parameter at wavelength 'lambda' [m],
; lambda = wavelength at which r0 is defined.
;
; Marcel Carbillet [marcel.carbillet@unice.fr],
; UMR 7293 Lagrange (UNS/CNRS/OCA), February 2013.
;
; Last modification: Feb. 2014
;
phase = (randomu(seed,dim,dim)-.5) * 2*!PI   ; rnd uniformly distributed phase
                                             ; (between -PI and +PI)
rr = dist(dim)
if L0 eq !VALUES.F_INFINITY then rr[0,0] = 1.; avoid 1/infinity afterwards
                                             ; for Kolmogorov model
modul = (rr^2+(length/L0)^2)^(-11/12.)       ; vonKarman/Kolmogorov model
if L0 eq !VALUES.F_INFINITY then modul[0,0] = 0.
                                             ; put again modulus[0,0]=0
                                             ; for Kolmogorov model
screen = fft(modul*exp(complex(0,1)*phase), /INVERSE)
                                             ; compute wf
screen *= sqrt(2)*sqrt(.0228)*(length/r0)^(5/6.)*lambda/(2*!PI)
                                             ; proper normalization of wf
                                             ; (considering an r0 at lambda)
screen -= mean(screen)

return, screen                               ; deliver 2 independent wf:
                                             ; float(screen) & imaginary(screen)
end